![geomapiLogo](https://gitlab.kuleuven.be/uploads/-/system/project/avatar/7619/GeoMapiLogo.png?width=64)

# GeomAPI

A joint API to standardize geomatic data storage and processing.


## Installation

Use the package manager [pip](https://pypi.org/project/geomapi) to install geomapi.

```bash
pip install geomapi
```

## Documentation

You can read the full API reference here:
[Documentation](https://geomatics.pages.gitlab.kuleuven.be/research-projects/geomapi/)


## Quickstart

```py
import geomapi
from geomapi.nodes import Node

newNode = Node()
```

## Licensing

The code in this project is licensed under GNU license.
